#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Crée le Wed Feb 16 19:59:00 2022

@auteur: David ALBERTO
(www.astrolabe-science.fr)
"""
import matplotlib.pyplot as plt
import matplotlib as mpl#Normalisation des valeurs
import matplotlib.colorbar as cbar#barres de couleurs
import numpy as np#pour remplacer les valeurs absentes par 'NaN' (Not a Number)
from mpl_toolkits.axes_grid1 import make_axes_locatable#positionner les barres de couleurs
import pandas as pd

Zmax=118#on peut limiter aux premiers éléments chimiques
nom_grandeur='AbondanceUnivers'# pour accoler au nom du fichier (voir dernières lignes)

table = pd.read_csv("donnees_abondanceUniv.csv",
                    sep='\t',
                    )
liste_Z=table['Z']
liste_col=table['col']
liste_lig=table['lig']
liste_symb=table['symbole']
liste_abo=table['abondance']
liste_abo=np.log(liste_abo)/np.log(10)# passage en log10

# Réglages d'écriture du symbole des éléments :
taille_symbole=16
c_symbole='k'#couleur symbole

# Réglages d'écriture du numéro atomique :
x_offset_Z=-0.4
y_offset_Z=0.33
taille_Z=6
c_Z='k'#couleur numéro atomique

# Réglages d'écriture des terres rares :
y_offset_La=2.5#décalage vertical lanthanides
y_offset_Ac=y_offset_La#décalage vertical actinides

# Réglages d'écriture du nom des éléments :
x_offset_nom=-0.0
y_offset_nom=-0.4
c_nom='black'
taille_nom=6

noms=['Hydrogène','Hélium','Lithium','Béryllium','Bore','Carbone','Azote','Oxygène',
      'Fluor','Néon','Sodium','Magnésium','Aluminium','Silicium','Phosphore','Soufre',
      'Chlore','Argon','Potassium','Calcium','Scandium','Titane','Vanadium','Chrome',
      'Manganèse','Fer','Cobalt','Nickel','Cuivre','Zinc','Gallium','Germanium',
      'Arsenic','Sélénium','Brome','Krypton','Rubidium','Strontium','Yttrium',
      'Zirconium','Niobium','Molybdène','Technétium','Ruthénium','Rhodium',
      'Palladium','Argent','Cadmium','Indium',
'Étain','Antimoine','Tellure','Iode','Xénon','Césium','Baryum','Lanthane','Cérium',
'Praséodyme','Néodyme','Prométhium','Samarium','Europium','Gadolinium','Terbium',
'Dysprosium','Holmium','Erbium','Thulium','Ytterbium','Lutetium','Hafnium','Tantale',
'Tungstène','Rhénium','Osmium','Iridium','Platine','Or','Mercure','Thallium','Plomb',
'Bismuth','Polonium','Astate','Radon','Francium','Radium','Actinium','Thorium','Protactinium',
'Uranium','Neptunium','Plutonium','Americium','Curium','Berkelium','Californium','Einsteinium',
'Fermium','Mendelevium','Nobelium','Lawrencium','Rutherfordium','Dubnium','Seaborgium','Bohrium',
'Hassium','Meitnerium','Darmstadtium','Roentgenium','Copernicium','Nihonium','Flerovium',
'Moscovium','Livermorium','Tennessine','Oganesson',
]#le module mendeleev n'a que les noms des éléments en anglais
# ---------------------------------


a=1#espace horizontal
b=1#espace vertical
#############################################
# FONCTION :
def numeroscolonnes():#numérote les colonnes en haut
    for i in np.arange(1, 19):
        plt.text(a*(i), -0.4, "%s"%(i), fontsize=8, color='gray',
                 ha='center')

#############################################

# plt.rcParams["font.family"] = "Ubuntu"#ou autre police installée
#paramètres du graphique
fig=plt.figure(figsize=(29.7/2.54,21/2.54),tight_layout=True)
plt.rcParams.update({"text.usetex": True}) #utiliser la police LaTeX (optionnel)

"""
Attention, en modifiant les dimensions (figsize, et valeurs des paramètres a et b, les tailles des polices
devront sans doute être réajustées.
"""
plt.title(r"$\textsf{Abondance des éléments chimiques dans l'Univers}^*$", fontsize=20,y=0.85)

ax1=plt.subplot(111)
ax1.set_aspect('equal')

# plt.xlabel("Conductivité thermique (W/(mK))")
plt.xticks([])
plt.yticks([])
plt.ylim(-11*b, 1)
plt.xlim(0,19*a)

#gamme de couleurs choisie (colormap) :
cmap=plt.get_cmap('Purples')
"""
Les colormaps sont à choisir parmi les séquentiels :
'Greys', 'Purples', 'Blues', 'Greens', 'Oranges', 'Reds',
'YlOrBr', 'YlOrRd', 'OrRd', 'PuRd', 'RdPu', 'BuPu',
'GnBu', 'PuBu', 'YlGnBu', 'PuBuGn', 'BuGn', 'YlGn'
"""
#normalisation de la gamme de valeurs :
norm = mpl.colors.Normalize(vmin=min(liste_abo),vmax=max(liste_abo)) 

# #tracé des cases :
for n in range(len(liste_Z)):
    plt.text(liste_col[n]*a, -liste_lig[n]*b, liste_symb[n], fontsize=taille_symbole, va='center', ha='center')
    plt.text(liste_col[n]*a+x_offset_Z*a,-liste_lig[n]*b+y_offset_Z*b,liste_Z[n],c=c_Z,fontsize=taille_Z,ha='left')#numéro atomique
    plt.text(liste_col[n]*a+x_offset_nom*a,-liste_lig[n]*b+y_offset_nom*b,r'\textsf{%s}'%(noms[n]),c=c_nom,fontsize=taille_nom,ha='center')#nom
    if liste_abo[n] is np.nan:
        couleur_case='gainsboro'
    else:
        couleur_case=cmap(norm(liste_abo[n]))
    rectangle=plt.Rectangle((liste_col[n]*a-0.5*a,-(liste_lig[n]*b+0.5*b)),a,b,facecolor=couleur_case,edgecolor='white')#case
    ax1.add_patch(rectangle)

# numeroscolonnes()

#tracé de la barre de couleurs :
divider = make_axes_locatable(ax1)
cax = divider.append_axes('bottom', size='6%', pad=0.2)
cb=cbar.ColorbarBase(cax, cmap=cmap, norm=norm, orientation='horizontal')

#----------------------------------------------------------------------------------------
# signature
ax1.text(0.99,0.02,r'D. $\textsc{Alberto}$ (www.astrolabe-science.fr) Données : sciencenotes.org',
         rotation=90,
         fontsize=6,
         transform=ax1.transAxes)

# légende :
ax1.text(0.01,0.01,r'* pourcentage en masse, échelle logarithmique',
         fontsize=8,
         transform=ax1.transAxes)


fig.savefig("TableauPeriodique"+nom_grandeur+".pdf")
fig.savefig("TableauPeriodique"+nom_grandeur+".png",dpi=300)
# plt.show()
